@@ -1,4 +1,24 @@
-from .pluthon_sugar import *
+from .pluthon_ast import (
+    ByteString,
+    Integer,
+    Bool,
+    AST,
+    Apply,
+    Delay,
+    Ite,
+    Unit,
+    Force,
+    Pattern,
+)
+from .pluthon_sugar import (
+    EqualsByteString,
+    EqualsInteger,
+    EqualsBool,
+    PVar,
+    PLambda,
+    TraceError,
+)
+from dataclasses import field, dataclass
 import typing
 
 """
@@ -6,7 +26,10 @@ Functional Data Structures that can store anything (as opposed to PlutusData der
 
 Built on wrapped lambda terms
 """
-identity = lambda x: x
+
+
+def identity(x):
+    return x
 
 
 _BUILTIN_TYPE_MAP = {
@@ -58,8 +81,14 @@ class FunctionalMap(AST):
         return res
 
 
-def FunctionalMapAccess(m: AST, k: AST, default=TraceError("KeyError")):
-    return Force(Apply(m, k, Delay(default)))
+@dataclass
+class FunctionalMapAccess(Pattern):
+    m: AST
+    k: AST
+    default: AST = field(default_factory=lambda: TraceError("KeyError"))
+
+    def compose(self):
+        return Force(Apply(self.m, self.k, Delay(self.default)))
 
 
 TOPRIMITIVEVALUE = b"0"
